/*
 * getpagesize.c
 */


#include<sys/param.h>


int getpagesize()
{
	return PAGE_SIZE;
}
